@@ -3,6 +3,7 @@ from .auth import Auth
 from .front import Front
 from .helpers import LiveHelper, MultiredditHelper, SubredditHelper
 from .inbox import Inbox
+from .list.moderated import ModeratedList
 from .list.redditor import RedditorList
 from .list.trophy import TrophyList
 from .listing.domain import DomainListing
@@ -25,6 +26,7 @@ from .reddit.removal_reasons import RemovalReason
 from .reddit.rules import Rule
 from .reddit.submission import Submission
 from .reddit.subreddit import Subreddit
+from .reddit.user_subreddit import UserSubreddit
 from .reddit.widgets import (
     Button,
     ButtonWidget,
