@@ -16,7 +16,7 @@ from .redditor import Redditor
 from .subreddit import Subreddit
 
 if TYPE_CHECKING:  # pragma: no cover
-    from .... import asyncpraw
+    import asyncpraw
 
 
 class Comment(InboxableMixin, UserContentMixin, FullnameMixin, RedditBase):
