@@ -1,5 +1,13 @@
 """Provide the WikiPage class."""
-from typing import TYPE_CHECKING, Any, AsyncGenerator, Dict, Optional, Union
+from typing import (
+    TYPE_CHECKING,
+    Any,
+    AsyncGenerator,
+    AsyncIterator,
+    Dict,
+    Optional,
+    Union,
+)
 
 from ...const import API_PATH
 from ...util.cache import cachedproperty
@@ -8,7 +16,7 @@ from .base import RedditBase
 from .redditor import Redditor
 
 if TYPE_CHECKING:  # pragma: no cover
-    from .... import asyncpraw
+    import asyncpraw
 
 
 class WikiPageModeration:
@@ -74,6 +82,59 @@ class WikiPageModeration:
         )
         await self.wikipage._reddit.post(url, data=data)
 
+    async def revert(self):
+        """Revert a wikipage back to a specific revision.
+
+        To revert the page ``"praw_test"`` in ``r/test`` to revision ``[ID]``, try
+
+        .. code-block:: python
+
+            subreddit = await reddit.subreddit("test")
+            wikipage = await subreddit.wiki.get_page("praw_test")
+            revision = await wikipage.revision("[ID]")
+            await revision.mod.revert()
+
+        .. note::
+
+            When you attempt to revert the page ``config/stylesheet``, Reddit checks to
+            see if the revision being reverted to passes the CSS filter. If the check
+            fails, then the revision attempt will also fail, and a
+            ``prawcore.Forbidden`` exception will be raised. For example, you can't
+            revert to a revision that contains a link to ``url(%%PRAW%%)`` if there is
+            no image named ``PRAW`` on the current stylesheet.
+
+            Here is an example of how to look for this type of error:
+
+            .. code-block:: python
+
+                from asyncprawcore.exceptions import Forbidden
+
+                try:
+                    subreddit = await reddit.subreddit("test")
+                    wikipage = await subreddit.wiki.get_page("config/stylesheet")
+                    revision = await wikipage.revision("[ID]")
+                    await revision.mod.revert()
+                except Forbidden as exception:
+                    try:
+                        await exception.response.json()
+                    except ValueError:
+                        exception.response.text
+
+            If the error occurs, the output will look something like
+
+            .. code-block:: python
+
+                {"reason": "INVALID_CSS", "message": "Forbidden", "explanation": "%(css_error)s"}
+
+        """
+        await self.wikipage._reddit.post(
+            API_PATH["wiki_revert"].format(subreddit=self.wikipage.subreddit),
+            data={
+                "page": self.wikipage.name,
+                "revision": self.wikipage._revision,
+            },
+        )
+
     async def settings(self) -> Dict[str, Any]:
         """Return the settings for this WikiPage."""
         url = API_PATH["wiki_page_settings"].format(
@@ -255,6 +316,35 @@ class WikiPage(RedditBase):
             data=other_settings,
         )
 
+    def discussions(
+        self, **generator_kwargs: Any
+    ) -> AsyncIterator["asyncpraw.models.Submission"]:
+        """Return a :class:`.ListingGenerator` for discussions of a wiki page.
+
+        Discussions are site-wide links to a wiki page.
+
+        Additional keyword arguments are passed in the initialization of
+        :class:`.ListingGenerator`.
+
+        To view the titles of discussions of the page ``"praw_test"`` in ``r/test``,
+        try:
+
+        .. code-block:: python
+
+            subreddit = await reddit.subreddit("test")
+            wikipage = await subreddit.get_page("praw_test")
+            async for submission in wikipage.discussions():
+                print(submission.title)
+
+        """
+        return ListingGenerator(
+            self._reddit,
+            API_PATH["wiki_discussions"].format(
+                subreddit=self.subreddit, page=self.name
+            ),
+            **generator_kwargs,
+        )
+
     async def revision(self, revision: str):
         """Return a specific version of this page by revision ID.
 
